@@ -9,15 +9,15 @@ generaloptimizationNEW=function(etas.obj,
 n       =nrow(etas.obj$cat)
 params  =c(etas.obj$params,etas.obj$betacov)
 
+etas.obj$nstep.par=etas.obj$nstep.par+1
 
 
-
-
+if (iprint){
 print("params in general optimization")
 print(params)
 print(etas.obj$nparams)
 print(etas.obj$nparams.etas)
-                
+}                
                                   etas.obj$dettrasf=replicate(n,1)
 
                
@@ -28,6 +28,7 @@ if (etas.obj$usenlm){risult =nlm(etas.mod2NEW,params,
 		typsize=abs(params),
 		hessian=hessian,
 		iterlim		=iterlim,
+		params.lim=etas.obj$params.lim, # added 2021
 		etas.obj=etas.obj
 		)
 		params.optim=risult$estimate
@@ -37,6 +38,8 @@ else {
 	
 risult =optim(params,etas.mod2NEW,
 		method	=etas.obj$method,
+		params.lim=etas.obj$params.lim, # added 2021
+		
 		hessian	=hessian,		control=list(trace=2,maxit=iterlim,fnscale=n/diff(range(etas.obj$cat$time.work)),parscale=sqrt(exp(params))),
  		etas.obj=etas.obj
 )
