@@ -1,5 +1,8 @@
 kde2dnew.fortran <-
-function(xkern,ykern,gx,gy,h,factor.xy=1,eps=0,w=replicate(length(xkern),1),
+function(
+#        parallel=FALSE,
+         xkern,ykern,gx,gy,h,
+         factor.xy=1,eps=0,w=replicate(length(xkern),1),
 hvarx=replicate(length(xkern),1),hvary=replicate(length(xkern),1)
 )
 {
